@@ -1,6 +1,7 @@
 from __future__ import annotations
 
 import logging
+import os
 from ast import literal_eval
 from configparser import ConfigParser
 from itertools import islice
@@ -25,7 +26,7 @@ class DocumentFileRepository:
         if not dir_path.is_dir():
             raise NotADirectoryError(f'The given path {dir_path} does not point to an existing directory!')
         if at_least_two and (not any(self._list_files()) or not next(islice(self._list_files(), 1, None), None)):
-            raise NoDocumentFilePairFoundError(f'The directory {dir_path} must contain at least two documents.')
+            raise NoDocumentFilePairFoundError(f"The directory '{dir_path}' must contain at least two documents.")
 
     def _list_files(self):
         if self._recursive:
@@ -36,7 +37,7 @@ class DocumentFileRepository:
     def list(self) -> set[Document]:
         files = list(self._list_files())
         docs = thread_map(self._read_file, files, desc=f"Reading documents in '{self._dir_path}'",
-                          unit='doc', total=len(files))
+                          unit='doc', total=len(files), max_workers=os.cpu_count())
         return set(filter(None, docs))
 
     def _read_file(self, file):
@@ -60,7 +61,7 @@ class DocumentFileRepository:
 class DocumentPairReportFileRepository:
     def __init__(self, out_path: Path):
         if not out_path.is_dir():
-            raise NotADirectoryError(f'The given path {out_path} does not point to an existing directory!')
+            raise NotADirectoryError(f"The given path '{out_path}' does not point to an existing directory!")
         self._out_path = out_path
 
     def add(self, doc_pair_report):
